/// <reference types="node" />
import * as net from 'net';
import * as tls from 'tls';
import { TokenAPI } from './TokenAPI';
export declare type TokenClientOptions = tls.ConnectionOptions & net.SocketConstructorOpts;
export declare const defaultTokenClientOptions: TokenClientOptions;
export interface TokenClient extends TokenAPI {
    on(event: 'remoteClose', listener: () => void): this;
    on(event: string, listener: (...args: any[]) => void): this;
    once(event: 'remoteClose', listener: () => void): this;
    once(event: string, listener: (...args: any[]) => void): this;
    emit(event: 'remoteClose'): boolean;
    emit(event: string, ...args: any[]): boolean;
}
export declare class TokenClient extends TokenAPI {
    private options;
    private socket;
    private connection;
    private hadError;
    constructor(options: TokenClientOptions);
    close(): boolean;
    connect(): boolean;
    /**
     * Send a token to the server.
     * Returns true if the token was written to the connection.
     * @param token The token to transmit to the server.
     */
    send(token: Buffer): boolean;
    /**
     * Applies initial event listeners.
     */
    private applyListeners();
    /**
     * Creates a new connection object for the socket.
     */
    private updateConnection();
}
